@@ -19,7 +19,7 @@ class Parser:
     AttributeObj = Attribute
     EventObj = Event
 
-    def __init__(self, src, tempDir='templates', indexName='index', obj={}, models=None, events=None):
+    def __init__(self, src, tempDir='templates', indexName='index', obj={}, models=None, events=None, debug=False):
         self.env = Environment(loader=FileSystemLoader(searchpath=os.path.join(src, tempDir), encoding='utf-8'))
         self.obj = obj
         self.qtClass = {} #重载的Qt类，build的时候发现有特殊指定会使用重新定义的类来覆盖原有的类
@@ -28,6 +28,7 @@ class Parser:
         self.btnGroups = {} #按键组
         self.models = models
         self.events = events
+        self.debug = debug
 
     def addQtClass(self, name, obj): #必须在build之前使用才有效
         self.qtClass[name] = obj
